@@ -8,6 +8,7 @@ llm = typer.Typer(short_help="The LLM management.")
 def serve(
     model: str = typer.Argument("", help="The ID of the LLM model to use."),
     model_name: str = typer.Argument("", help="The name of the LLM model to use."),
+    parallal_size: int = typer.Option(1, help="The number of GPUs to use."),
     host: str = typer.Option("0.0.0.0", help="The host of the server."),
     port: int = typer.Option(8000, help="The port of the server."),
 ):
@@ -77,7 +78,7 @@ def download(
 ):
     from mw_python_sdk import download_file, download_dir
 
-    if recursive:
+    if recursive or source is None:
         downloaded_dir = download_dir(dataset, sub_dir=source, local_dir=destination)
         print(f"Successfully downloaded to {downloaded_dir}")
         return
