@@ -12,6 +12,7 @@ def serve(
     port: int = 8080,
     dtype: str = "half",
     max_model_len: int = 4096,
+    tensor_parallel_size: int = 1,
 ):
     if model_id == "_echo_":
         uvicorn.run("mw_python_sdk.llm.echo_server:app", host=host, port=port)
@@ -23,7 +24,7 @@ def serve(
             [
                 "bash",
                 "-c",
-                f"python -m vllm.entrypoints.openai.api_server --max-model-len={max_model_len}  --served-model-name={model_name} --dtype={dtype} --model '{model_dir}' --host {host} --port {port}",
+                f"python -m vllm.entrypoints.openai.api_server --tensor-parallel-size {tensor_parallel_size} --max-model-len={max_model_len}  --served-model-name={model_name} --dtype={dtype} --model '{model_dir}' --host {host} --port {port}",
             ]
         )
 
